==> components-1.2.14.tgz: package/es/v1/ListItem/ListItemWithRadio.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import Radio from '../Radio/Radio';
import { Box } from '../Layout';
import ListContainer from './ListContainer';
import { ListItemWithRadioDefaultProps } from '../../ListItem/props/defaultProps';
import { ListItemWithRadio_Props } from '../../ListItem/props/propTypes';
import style from '../../ListItem/ListItem.module.css';

const ListItemWithRadio = props => {
  let {
    size,
    active,
    highlight,
    value,
    checked,
    autoHover,
    palette,
    id,
    dataId,
    dataSelectorId,
    title,
    isDisabled,
    disableTitle,
    a11y,
    customClass,
    customProps,
    needMultiLineText,
    getRef,
    onClick,
    onHover,
    index
  } = props;
  let {
    ListItemProps = {},
    ContainerProps = {}
  } = customProps;
  const listA11y = {
    role: 'option',
    ...a11y
  };

  function handleRef(ele) {
    getRef && getRef(ele, index);
  }

  function handleClick(e) {
    onClick && onClick(id, value, index, e);
  }

  function handleHover(e) {
    onHover && onHover(id, value, index, e);
  }

  let {
    customListItem = '',
    customRadio = '',
    customRadioWrap = ''
  } = customClass;
  return /*#__PURE__*/React.createElement(ListContainer, _extends({
    a11y: listA11y,
    size: size,
    palette: palette,
    highlight: highlight,
    isDisabled: isDisabled,
    active: active,
    autoHover: autoHover,
    customClass: customListItem,
    dataId: dataId,
    dataSelectorId: dataSelectorId,
    onClick: handleClick,
    onMouseOver: handleHover,
    eleRef: handleRef,
    disableTitle: disableTitle,
    title: null,
    customProps: ListItemProps
  }, ContainerProps), /*#__PURE__*/React.createElement(Box, {
    className: style.iconBox
  }, /*#__PURE__*/React.createElement(Radio, {
    checked: checked,
    id: id,
    a11y: {
      ariaHidden: true
    },
    customClass: {
      customRadio: customRadio,
      customRadioWrap: customRadioWrap
    }
  })), /*#__PURE__*/React.createElement(Box, {
    flexible: true,
    shrink: true,
    "data-title": disableTitle ? null : title,
    className: needMultiLineText ? style.multiLineValue : style.value
  }, value));
};

export default ListItemWithRadio;
ListItemWithRadio.defaultProps = ListItemWithRadioDefaultProps;
ListItemWithRadio.propTypes = ListItemWithRadio_Props; // if (__DOCS__) {
//   ListItemWithRadio.docs = {
//     componentGroup: 'Molecule',
//     folderName: 'Style Guide'
//   };
// }

==> components-1.2.45.tgz: package/es/v1/ListItem/ListItemWithRadio.js <==
import React from 'react';
import Radio from "../Radio/Radio";
import { Box } from "../Layout";
import ListContainer from "./ListContainer";
import { ListItemWithRadioDefaultProps } from "./props/defaultProps";
import { ListItemWithRadio_Props } from "./props/propTypes";
import style from "../../ListItem/ListItem.module.css";

const ListItemWithRadio = props => {
  let {
    size,
    active,
    highlight,
    value,
    checked,
    autoHover,
    palette,
    id,
    dataId,
    dataSelectorId,
    title,
    isDisabled,
    disableTitle,
    a11y,
    customClass,
    customProps,
    needMultiLineText,
    getRef,
    onClick,
    onHover,
    index
  } = props;
  let {
    ListItemProps = {},
    ContainerProps = {}
  } = customProps;
  const listA11y = {
    role: 'option',
    ...a11y
  };

  function handleRef(ele) {
    getRef && getRef(ele, index);
  }

  function handleClick(e) {
    onClick && onClick(id, value, index, e);
  }

  function handleHover(e) {
    onHover && onHover(id, value, index, e);
  }

  let {
    customListItem = '',
    customRadio = '',
    customRadioWrap = ''
  } = customClass;
  return /*#__PURE__*/React.createElement(ListContainer, {
    a11y: listA11y,
    size: size,
    palette: palette,
    highlight: highlight,
    isDisabled: isDisabled,
    active: active,
    autoHover: autoHover,
    customClass: customListItem,
    dataId: dataId,
    dataSelectorId: dataSelectorId,
    onClick: handleClick,
    onMouseOver: handleHover,
    eleRef: handleRef,
    disableTitle: disableTitle,
    title: null,
    customProps: ListItemProps,
    ...ContainerProps
  }, /*#__PURE__*/React.createElement(Box, {
    className: style.iconBox,
    dataId: `${dataId}_radio`
  }, /*#__PURE__*/React.createElement(Radio, {
    checked: checked,
    id: id,
    a11y: {
      ariaHidden: true
    },
    customClass: {
      customRadio: customRadio,
      customRadioWrap: customRadioWrap
    }
  })), /*#__PURE__*/React.createElement(Box, {
    flexible: true,
    shrink: true,
    "data-title": disableTitle ? null : title,
    className: needMultiLineText ? style.multiLineValue : style.value
  }, value));
};

export default ListItemWithRadio;
ListItemWithRadio.defaultProps = ListItemWithRadioDefaultProps;
ListItemWithRadio.propTypes = ListItemWithRadio_Props; // if (__DOCS__) {
//   ListItemWithRadio.docs = {
//     componentGroup: 'Molecule',
//     folderName: 'Style Guide'
//   };
// }
